# -*- coding: utf-8 -*-
"""
__init__.py file for forecastiopy module.
Defines the __all__ modules.
"""

__all__ = ['ForecastIO', 'FIOCurrently', 'FIOMinutely', \
           'FIOHourly', 'FIODaily', 'FIOFlags', 'FIOAlerts']
